<?php
class RecentPostsWidget extends WP_Widget
{
	function __construct() {
		parent::__construct(
			'flexible-recent-posts-widget',
			__( 'Flexible Recent Posts', 'frp' ),
			array( 'description' => __( 'Displays recent posts with the given template', 'frp' ) ),
			array( 'width'  => 400, 'height' => 350 )
		);


		if ( is_active_widget(false, false, $this->id_base) ) {
			add_action( 'wp_head', array( &$this, 'enqueue_styles' ) );
		}
	}

	function parse_instance_args( $instance ) {
		$instance = wp_parse_args( (array)$instance,
			array(
				'title'				   => '',
				'number'				   => 2,
				'all_posts_link_title'  => false,
				'all_posts_link_footer' => true,
				'all_posts_title'	       => __( 'All news', 'frp' ) . ' &gt;&gt;',
				'all_posts_link'		   => '',
				'template'               => '',
				'all_categories'		   => true,
				'categories'			   => array()
			)
		);

		if ( empty( $instance['template'] ) ) {
			ob_start();
			require( plugin_dir_path( __FILE__ ) . 'templates/single-post-template.php' );
			$instance['template'] = ob_get_contents();
			ob_end_clean();
		}

		return $instance;
	}

	function enqueue_styles() {
		wp_enqueue_style( 'frp-frontend', plugins_url( 'css/frp-front.css', __FILE__ ) );
	}

	function widget( $args, $instance ) {
		extract( $args );

		$instance = $this->parse_instance_args( $instance );

		// If all categories checkbox is set, then we set categories list to empty and we will get all posts.
		if ( $instance['all_categories'] ) {
			$instance['categories'] = array();
		}

		$instance['categories'] = apply_filters( 'frp_categories', $instance['categories'] );
		$instance['all_posts_title'] = htmlspecialchars( $instance['all_posts_title'] );

		if ( !empty( $instance['categories'] ) || $instance['all_categories'] ) {
			$posts = get_posts(
				array(
					'numberposts' => $instance['number'],
					'category'	=> implode( ',', $instance['categories'] ),
				)
			);

			if ( !empty( $posts ) ) {
				$category_link = ( empty( $instance['all_posts_link'] ) ) ? get_category_link( end( $instance['categories'] ) ) : $instance['all_posts_link'];

				require( 'templates/recent-posts-widget.php' );
			}
		}
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = $new_instance['number'];
		$instance['template'] = $new_instance['template'];
		$instance['categories'] = $_POST['post_category'];
		$instance['all_categories'] = isset( $new_instance['all_categories'] ) ? true : false;
		$instance['all_posts_link_title'] = isset( $new_instance['all_posts_link_title'] ) ? true : false;
		$instance['all_posts_link_footer'] = isset( $new_instance['all_posts_link_footer'] ) ? true : false;
		$instance['all_posts_title'] = strip_tags( $new_instance['all_posts_title'] );
		$instance['all_posts_link'] = '';
		if ( !empty( $new_instance['all_posts_link'] ) ) {
			$instance['all_posts_link'] = strip_tags( $new_instance['all_posts_link'] );
		}

		return $instance;
	}

	function form( $instance ) {
		$plugin_dir = plugin_dir_url( __FILE__ );

		$instance = $this->parse_instance_args( $instance );

		$title = strip_tags( $instance['title'] );
		$template = esc_textarea( $instance['template'] );

		require( 'templates/recent-posts-form.php' );
	}
}

?>