<?php
/*
Plugin Name: Flexible Recent Posts
Plugin URI: http://steelrat.info/
Description: Displaying recent posts widget with predefined template.
Version: 0.1
Author: SteelRat
Author URI: http://steelrat.info/
License: GPLv2 or later
*/

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
add_action( 'widgets_init', 'frp_widgets_init' );

add_action( 'admin_print_styles-widgets.php', 'frp_admin_print_styles_widgets' );
add_action( 'admin_print_scripts-widgets.php', 'frp_admin_print_scripts_widgets' );

add_shortcode( 'frp_title', 'frp_title' );
add_shortcode( 'frp_thumbnail', 'frp_thumbnail' );
add_shortcode( 'frp_excerpt', 'frp_excerpt' );
add_shortcode( 'frp_date', 'frp_date' );
add_shortcode( 'frp_link', 'frp_link' );

function frp_admin_print_scripts_widgets() {
	wp_enqueue_script( 'rangyinputs', plugins_url( '', __FILE__ ) . '/scripts/textinputs_jquery.js', array( 'jquery' ) );
	wp_enqueue_script( 'frp', plugins_url( '', __FILE__ ) . '/scripts/frp.js', array( 'jquery', 'rangyinputs' ) );

	$options = array(
		'shortcodes' => array(
			'title'       => '[frp_title]',
			'thumbnail'   => '[frp_thumbnail size="32x32"]',
			'excerpt'     => '[frp_excerpt]',
			'date'        => '[frp_date format="d.m.Y"]',
			'link'        => '[frp_link]',
		),
		'flattrLink' => 'http://flattr.com/thing/646464/Wordpress-Flexible-Recent-Posts-plugin'
	);

	wp_localize_script( 'frp', 'frpOptions', $options );
}

function frp_admin_print_styles_widgets() {
	// Load native stylesheet for editor buttons.
	wp_print_styles( 'editor-buttons' );

	wp_enqueue_style( 'frp', plugins_url( '', __FILE__ ) . '/css/frp-admin.css' );
}

function frp_widgets_init() {
	load_plugin_textdomain( 'frp', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

	require_once( 'class-recent-posts-widget.php' );

	register_widget( 'RecentPostsWidget' );
}

function frp_title() {
	global $frp_current_post;

	if ( isset( $frp_current_post ) ) {
		$title = $frp_current_post->post_title;
	} else {
		$title = '';
	}

	return $title;
}

function frp_excerpt() {
	global $frp_current_post, $page, $pages;

	if ( isset( $frp_current_post ) ) {
		// Replacing current pages with our widget's page to make filter work properly.
		$temp_pages = $pages;
		$temp_page = $page;
		$page = 1;
		$pages[0] = $frp_current_post->post_content;

		$excerpt = get_the_excerpt();

		// Restore current pages.
		$page = $temp_page;
		$pages = $temp_pages;
	} else {
		$excerpt = '';
	}

	return $excerpt;
}

function frp_date( $atts ) {
	global $frp_current_post;

	if ( isset( $frp_current_post ) ) {
		$atts = shortcode_atts( array(
			'format' => get_option( 'date_format' ),
		), $atts );
		$date = mysql2date( $atts['format'], $frp_current_post->post_date );
	} else {
		$date = '';
	}

	return $date;
}

function frp_thumbnail( $atts ) {
	global $frp_current_post;
	$thumbnail = '';

	if ( isset( $frp_current_post ) ) {
		$atts = shortcode_atts( array(
			'size' => '32x32',
		), $atts );

		if ( preg_match( '/^(\d+)x(\d+)$/', $atts['size'], $size ) == 1 ) {
			// Remove first element from array. It's matched line. Leave only two sizes.
			unset( $size[0] );
			$atts['size'] = $size;
		}

		$thumbnail = get_the_post_thumbnail( $frp_current_post->ID, $atts['size'] );
	}

	return $thumbnail;
}

function frp_link() {
	global $frp_current_post;

	if ( isset( $frp_current_post ) ) {
		$link = get_permalink( $frp_current_post->ID );
	} else {
		$link = '';
	}

	return $link;
}

?>